@@ -23,9 +23,11 @@
 #include "inputdata.h"
 #include "asm.h"
 
+extern struct colm_sections rl_parse;
+
 int main( int argc, const char **argv )
 {
-	InputData id( &hostLangAsm );
+	InputData id( &hostLangAsm, &rl_parse, 0 );
 	return id.main( argc, argv );
 }
 
